<?php
/*
Plugin Name: Affiliate Machine
Plugin URI: http://www.20script.ir
Description: The plugin adds affiliate link to relevant keywords.
Version: 1.31
Author: 20Script.ir
Author URI: http://www.20script.ir
*/
define('AFFILIATEMACHINE_RECORDS_PER_PAGE', '20');
define('AFFILIATEMACHINE_VERSION', 1.31);

wp_enqueue_script("jquery");
register_activation_hook(__FILE__, array("affiliatemachine_class", "install"));

class affiliatemachine_class {
	var $options;
	var $error;
	var $info;
	var $forbidden_keywords = array("script", "style", "strong", "span", "iframe", "embed", "object", "textarea", "input");
	var $modes = array("all", "post", "none");
	var $replacement_default_options = array(
		"keyword_color" => "#BC3415",
		"keyword_frame" => "off",
		"keyword_underline" => "off",
		"keyword_bold" => "off",
		"link_target" => "on",
		"link_nofollow" => "on",
		"max_keywords" => 0
	);
	
	function __construct() {
		if (function_exists('load_plugin_textdomain')) {
			load_plugin_textdomain('affiliatemachine', false, dirname(plugin_basename(__FILE__)).'/languages/');
		}
		$this->options = array (
			"version" => AFFILIATEMACHINE_VERSION
		);

		if (!empty($_COOKIE["affiliatemachine_error"])) {
			$this->error = stripslashes($_COOKIE["affiliatemachine_error"]);
			setcookie("affiliatemachine_error", "", time()+30, "/", ".".str_replace("www.", "", $_SERVER["SERVER_NAME"]));
		}
		if (!empty($_COOKIE["affiliatemachine_info"])) {
			$this->info = stripslashes($_COOKIE["affiliatemachine_info"]);
			setcookie("affiliatemachine_info", "", time()+30, "/", ".".str_replace("www.", "", $_SERVER["SERVER_NAME"]));
		}

		if (is_admin()) {
			add_action('admin_menu', array(&$this, 'admin_menu'));
			add_action('init', array(&$this, 'admin_request_handler'));
			add_action('admin_head', array(&$this, 'admin_header'), 15);
			if (isset($_GET['page']) && $_GET['page'] == 'affiliate-machine-add') {
				wp_enqueue_style( 'farbtastic' );
				wp_enqueue_script( 'farbtastic' );
			}
			add_action('admin_menu', array(&$this, 'add_meta'));
			add_action('save_post', array(&$this, 'save_meta'));
		} else {
			add_action('wp_head', array(&$this, 'front_header'), 15);
			add_filter('the_content', array(&$this, 'the_content'), 1);
			add_filter('the_excerpt', array(&$this, 'the_content'), 1);
			add_filter('comment_text', array(&$this, 'the_content'), 99);
		}
	}

	function get_meta($post_id) {
		$meta = array();
		$meta["replacements"] = htmlspecialchars_decode(get_post_meta($post_id, 'affiliatemachine_replacements', true));
		return $meta;
	}

	function add_meta() {
		add_meta_box("affiliatemachine", '<img class="affiliatemachine_icon" src="'.plugins_url('/images/link.png', __FILE__).'" alt="Affiliate Machine" title="Affiliate Machine"> Affiliate Machine', array(&$this, 'show_meta'), "post", "normal", "high");
		add_meta_box("affiliatemachine", '<img class="affiliatemachine_icon" src="'.plugins_url('/images/link.png', __FILE__).'" alt="Affiliate Machine" title="Affiliate Machine"> Affiliate Machine', array(&$this, 'show_meta'), "page", "normal", "high");
		$post_types = get_post_types(array('public' => true, '_builtin' => false), 'names', 'and'); 
		foreach ($post_types as $post_type ) {
			add_meta_box("affiliatemachine", '<img class="affiliatemachine_icon" src="'.plugins_url('/images/link.png', __FILE__).'" alt="Affiliate Machine" title="Affiliate Machine"> Affiliate Machine', array(&$this, 'show_meta'), $post_type, "normal", "high");
		}		
	}
	
	function show_meta() {
		global $post, $wpdb;
		$meta = $this->get_meta($post->ID);
		$replacements = explode(',', $meta['replacements']);
		$sql = "SELECT * FROM ".$wpdb->prefix."am_replacements WHERE deleted = '0' ORDER BY created DESC";
		$rows = $wpdb->get_results($sql, ARRAY_A);
		
		wp_nonce_field(basename(__FILE__), 'affiliatemachine-nonce');
		print ('
			<table class="affiliatemachine_useroptions">
			<tr>
				<th style="width: 100px;">'.__('Replacements', 'affiliatemachine').':</th>
				<td>');
		if (sizeof($rows) > 0) {
			foreach ($rows as $row) {
				print ('
					<input type="checkbox" id="affiliatemachine_'.$row['id'].'" name="affiliatemachine_'.$row['id'].'" '.(in_array($row['id'], $replacements) ? ' checked="checked"' : '').'> '.htmlspecialchars($row['name'], ENT_QUOTES).'<br />');
			}
		} else {
			print (
			__('Create your first replacement <a href="admin.php?page=affiliate-machine-add">here</a>.', 'affiliatemachine'));
		}
		print ('		
				</td>
			</tr>
			</table>');
	}

	function save_meta($post_id) {
		$post_type_object = get_post_type_object($_POST['post_type']);

		if ((defined('DOING_AUTOSAVE') && DOING_AUTOSAVE)
		|| (!isset($_POST['post_ID']) || $post_id != $_POST['post_ID'])
		|| (!check_admin_referer(basename(__FILE__), 'affiliatemachine-nonce'))
		|| (!current_user_can($post_type_object->cap->edit_post, $post_id))) {
			return $post_id;
		}
		$replacements = array();
		foreach($_POST as $key => $value) {
			if (substr($key, 0, strlen('affiliatemachine_')) == 'affiliatemachine_') {
				$replacements[] = intval(substr($key, strlen('affiliatemachine_')));
			}
		}
		if (sizeof($replacements) == 0) delete_post_meta($post_id, "affiliatemachine_replacements");
		else update_post_meta($post_id, "affiliatemachine_replacements", implode(',', $replacements));
	}

	function install () {
		global $wpdb;
		$sql = "CREATE TABLE ".$wpdb->prefix."am_replacements (
			id int(11) NOT NULL auto_increment,
			mode varchar(15) collate utf8_unicode_ci NOT NULL,
			name varchar(255) collate utf8_unicode_ci NOT NULL,
			keywords text collate utf8_unicode_ci NOT NULL,
			url varchar(255) collate utf8_unicode_ci NOT NULL,
			options text NOT NULL,
			created int(11) NOT NULL,
			deleted int(11) NOT NULL default '0',
			UNIQUE KEY  id (id)
		);";
		require_once(ABSPATH . 'wp-admin/includes/upgrade.php');
		dbDelta($sql);
	}

	function admin_menu() {
		if (get_bloginfo('version') >= 3.0) {
			define("AFFILIATEMACHINE_PERMISSION", "add_users");
		}
		else{
			define("AFFILIATEMACHINE_PERMISSION", "edit_themes");
		}	
		add_menu_page(
			"Affiliate Machine"
			, "Affiliate Machine"
			, AFFILIATEMACHINE_PERMISSION
			, "affiliate-machine"
			, array(&$this, 'admin_replacements')
		);
		add_submenu_page(
			"affiliate-machine"
			, __('Replacements', 'affiliatemachine')
			, __('Replacements', 'affiliatemachine')
			, AFFILIATEMACHINE_PERMISSION
			, "affiliate-machine"
			, array(&$this, 'admin_replacements')
		);
		add_submenu_page(
			"affiliate-machine"
			, __('Add Replacement', 'affiliatemachine')
			, __('Add Replacement', 'affiliatemachine')
			, AFFILIATEMACHINE_PERMISSION
			, "affiliate-machine-add"
			, array(&$this, 'admin_add_replacement')
		);
	}

	function admin_replacements() {
		global $wpdb;

		if (isset($_GET["s"])) $search_query = trim(stripslashes($_GET["s"]));
		else $search_query = "";
		$tmp = $wpdb->get_row("SELECT COUNT(*) AS total FROM ".$wpdb->prefix."am_replacements WHERE deleted = '0'".((strlen($search_query) > 0) ? " AND name LIKE '%".addslashes($search_query)."%'" : ""), ARRAY_A);
		$total = $tmp["total"];
		$totalpages = ceil($total/AFFILIATEMACHINE_RECORDS_PER_PAGE);
		if ($totalpages == 0) $totalpages = 1;
		if (isset($_GET["p"])) $page = intval($_GET["p"]);
		else $page = 1;
		if ($page < 1 || $page > $totalpages) $page = 1;
		$switcher = $this->page_switcher(get_bloginfo("wpurl")."/wp-admin/admin.php?page=affiliate-machine".((strlen($search_query) > 0) ? "&s=".rawurlencode($search_query) : ""), $page, $totalpages);

		$sql = "SELECT * FROM ".$wpdb->prefix."am_replacements WHERE deleted = '0'".((strlen($search_query) > 0) ? " AND name LIKE '%".addslashes($search_query)."%'" : "")." ORDER BY created DESC LIMIT ".(($page-1)*AFFILIATEMACHINE_RECORDS_PER_PAGE).", ".AFFILIATEMACHINE_RECORDS_PER_PAGE;
		$rows = $wpdb->get_results($sql, ARRAY_A);
		if (!empty($this->error)) $message = "<div class='error'><p>".$this->error."</p></div>";
		if (!empty($this->info)) $message = "<div class='updated'><p>".$this->info."</p></div>";

		print ('
			<div class="wrap admin_affiliatemachine_wrap">
				<div id="icon-link-manager" class="icon32"><br /></div><h2>'.__('Affiliate Machine', 'affiliatemachine').'</h2><br />
				'.$message.'
				<form action="'.get_bloginfo("wpurl").'/wp-admin/admin.php" method="get" style="margin-bottom: 10px;">
				<input type="hidden" name="page" value="affiliate-machine" />
				'.__('Search:', 'affiliatemachine').' <input type="text" name="s" value="'.htmlspecialchars($search_query, ENT_QUOTES).'">
				<input type="submit" class="button-secondary action" value="'.__('Search', 'affiliatemachine').'" />
				'.((strlen($search_query) > 0) ? '<input type="button" class="button-secondary action" value="'.__('Reset search results', 'affiliatemachine').'" onclick="window.location.href=\''.get_bloginfo("wpurl").'/wp-admin/admin.php?page=affiliate-machine\';" />' : '').'
				</form>
				<div class="affiliatemachine_buttons"><a class="button" href="'.get_bloginfo("wpurl").'/wp-admin/admin.php?page=affiliate-machine-add">'.__('Create New Replacement', 'affiliatemachine').'</a></div>
				<div class="affiliatemachine_pageswitcher">'.$switcher.'</div>
				<table class="affiliatemachine_replacements">
				<tr>
					<th>'.__('Affiliate Link', 'affiliatemachine').'</th>
					<th>'.__('Keywords', 'affiliatemachine').'</th>
					<th style="width: 80px;">'.__('Operations', 'affiliatemachine').'</th>
				</tr>
		');
		if (sizeof($rows) > 0) {
			foreach ($rows as $row) {
				$bg_color = "";
				print ('
				<tr>
					<td><strong>'.htmlspecialchars($row['name'], ENT_QUOTES).'</strong><br />'.(!empty($row['url']) ? '<a href="'.$row['url'].'" title="'.htmlspecialchars($row['name'], ENT_QUOTES).'">'.htmlspecialchars($this->cut_string($row['url'], 40), ENT_QUOTES) : 'Link: none').'</em></td>
					<td>'.htmlspecialchars($row['keywords'], ENT_QUOTES).'</td>
					<td style="text-align: center;">
						<a href="'.get_bloginfo("wpurl").'/wp-admin/admin.php?page=affiliate-machine-add&id='.$row['id'].'" title="'.__('Edit replacement details', 'affiliatemachine').'"><img src="'.plugins_url('/images/edit.png', __FILE__).'" alt="'.__('Edit replacement details', 'affiliatemachine').'" border="0"></a>
						<a href="'.get_bloginfo("wpurl").'/wp-admin/admin.php?ak_action=affiliatemachine_delete&id='.$row['id'].'" title="'.__('Delete replacement', 'affiliatemachine').'" onclick="return affiliatemachine_submitOperation();"><img src="'.plugins_url('/images/delete.png', __FILE__).'" alt="'.__('Delete replacement', 'affiliatemachine').'" border="0"></a>
					</td>
				</tr>
				');
			}
		} else {
			print ('
				<tr><td colspan="3" style="padding: 20px; text-align: center;">'.((strlen($search_query) > 0) ? __('No results found for', 'affiliatemachine').' "<strong>'.htmlspecialchars($search_query, ENT_QUOTES).'</strong>"' : __('List is empty.', 'affiliatemachine')).'</td></tr>
			');
		}
		print ('
				</table>
				<div class="affiliatemachine_buttons"><a class="button" href="'.get_bloginfo("wpurl").'/wp-admin/admin.php?page=affiliate-machine-add">'.__('Create New Replacement', 'affiliatemachine').'</a></div>
				<div class="affiliatemachine_pageswitcher">'.$switcher.'</div>
				<div class="affiliatemachine_legend">
				<strong>Legend:</strong>
					<p><img src="'.plugins_url('/images/edit.png', __FILE__).'" alt="'.__('Edit replacement details', 'affiliatemachine').'" border="0"> '.__('Edit replacement details', 'affiliatemachine').'</p>
					<p><img src="'.plugins_url('/images/delete.png', __FILE__).'" alt="'.__('Delete replacement', 'affiliatemachine').'" border="0"> '.__('Delete replacement', 'affiliatemachine').'</p>
				</div>
			</div>
		');
	}

	function admin_add_replacement() {
		global $wpdb;

		unset($id);
		$status = "";
		if (isset($_GET["id"]) && !empty($_GET["id"])) {
			$id = intval($_GET["id"]);
			$replacement_details = $wpdb->get_row("SELECT * FROM ".$wpdb->prefix."am_replacements WHERE id = '".$id."' AND deleted = '0'", ARRAY_A);
			if (intval($replacement_details["id"]) == 0) unset($id);
		}
		if (empty($id)) $replacement_options = $this->replacement_default_options;
		else $replacement_options = $this->decode_options($id);
		
		$errors = true;
		if (!empty($this->error)) $message = "<div class='error'><p>".$this->error."</p></div>";
		else if (!empty($this->info)) $message = "<div class='updated'><p>".$this->info."</p></div>";
		$upload_dir = wp_upload_dir();
		print ('
		<div class="wrap admin_affiliatemachine_wrap">
			<div id="icon-link-manager" class="icon32"><br /></div><h2>'.(!empty($id) ? __('Affiliate Machine - Edit replacement', 'affiliatemachine') : __('Affiliate Machine - Add replacement', 'affiliatemachine')).'</h2>
			'.$message.'
			<form enctype="multipart/form-data" method="post" style="margin: 0px" action="'.get_bloginfo('wpurl').'/wp-admin/admin.php">
			<div class="postbox-container" style="width: 100%;">
				<div class="metabox-holder">
					<div class="meta-box-sortables ui-sortable">
						<div class="postbox">
							<!--<div class="handlediv" title="Click to toggle"><br></div>-->
							<h3 class="hndle" style="cursor: default;"><span>'.(!empty($id) ? __('Edit replacement', 'affiliatemachine') : __('Add replacement', 'affiliatemachine')).'</span></h3>
							<div class="inside">
								<table class="affiliatemachine_useroptions">
									<tr>
										<th>'.__('Mode', 'affiliatemachine').':</th>
										<td>
										<input type="radio" name="affiliatemachine_mode" id="affiliatemachine_mode_all" value="all"'.($replacement_details['mode'] == 'all' || empty($replacement_details['mode']) ? ' checked="checked"' : '').'> '.__('All website pages', 'affiliatemachine').'
										<br /><em>'.__('Set this option if you wish to use replacement on all pages of website.', 'affiliatemachine').'</em><br />
										<input type="radio" name="affiliatemachine_mode" id="affiliatemachine_mode_post" value="post"'.($replacement_details['mode'] == 'post' ? ' checked="checked"' : '').'> '.__('Particular posts/pages', 'affiliatemachine').'
										<br /><em>'.__('Set this option if you wish to use replacement on particular posts/pages. You can assign particular posts/pages on post/page editor.', 'affiliatemachine').'</em><br />
										<input type="radio" name="affiliatemachine_mode" id="affiliatemachine_mode_none" value="none"'.($replacement_details['mode'] == 'none' ? ' checked="checked"' : '').'> '.__('Disable replacement', 'affiliatemachine').'
										<br /><em>'.__('Set this option to disable replacement.', 'affiliatemachine').'</em>
										</td>
									</tr>
									<tr>
										<th>'.__('Title', 'affiliatemachine').':</th>
										<td><input type="text" name="affiliatemachine_name" id="affiliatemachine_name" value="'.(!empty($replacement_details['name']) ? htmlspecialchars($replacement_details['name'], ENT_QUOTES) : __('Default Title', 'affiliatemachine')).'" class="widefat"><br /><em>'.__('Enter the title of replacement.', 'affiliatemachine').'</em></td>
									</tr>
									<tr>
										<th>'.__('Keywords', 'affiliatemachine').':</th>
										<td><input type="text" name="affiliatemachine_keywords" id="affiliatemachine_keywords" value="'.htmlspecialchars($replacement_details['keywords'], ENT_QUOTES).'" class="widefat"><br /><em>'.__('Enter the keywords for replacement, comma-separated.', 'affiliatemachine').'</em></td>
									</tr>
									<tr>
										<th>'.__('Keyword color:', 'affiliatemachine').'</th>
										<td>
											<input type="text" id="affiliatemachine_keyword_color" name="affiliatemachine_keyword_color" value="'.htmlspecialchars($replacement_options['keyword_color'], ENT_QUOTES).'" style="width: 80px; text-align: right;">
											<div id="color_picker_affiliatemachine_keyword_color"></div>
											<br /><em>'.__('Please set keyword color.', 'affiliatemachine').'</em>
										</td>
									</tr>
									<tr>
										<th>'.__('Keyword highlight', 'affiliatemachine').':</th>
										<td>
											<input type="checkbox" name="affiliatemachine_keyword_frame" id="affiliatemachine_keyword_frame" '.($replacement_options['keyword_frame'] == 'on' ? ' checked="checked"' : '').'> '.__('Shadow frame', 'affiliatemachine').'
										</td>
									</tr>
									<tr>
										<th></th>
										<td>
											<input type="checkbox" name="affiliatemachine_keyword_underline" id="affiliatemachine_keyword_underline" '.($replacement_options['keyword_underline'] == 'on' ? ' checked="checked"' : '').'> '.__('Underline', 'affiliatemachine').'
										</td>
									</tr>
									<tr>
										<th></th>
										<td>
											<input type="checkbox" name="affiliatemachine_keyword_bold" id="affiliatemachine_keyword_bold" '.($replacement_options['keyword_bold'] == 'on' ? ' checked="checked"' : '').'> '.__('Bold font weight', 'affiliatemachine').'
										</td>
									</tr>
									<tr>
										<th>'.__('Affiliate URL', 'affiliatemachine').':</th>
										<td><input type="text" name="affiliatemachine_url" id="affiliatemachine_url" value="'.(!empty($replacement_details['url']) ? htmlspecialchars($replacement_details['url'], ENT_QUOTES) : get_bloginfo('wpurl')).'" class="widefat"><br /><em>'.__('Enter affiliate URL. The keywords will be hyperlinked with this URL.', 'affiliatemachine').'</em></td>
									</tr>
									<tr>
										<th>'.__('Link parameters', 'affiliatemachine').':</th>
										<td>
											<input type="checkbox" name="affiliatemachine_link_target" id="affiliatemachine_link_target" '.($replacement_options['link_target'] == 'on' ? ' checked="checked"' : '').'> '.__('Open link in new tab/window', 'affiliatemachine').'
										</td>
									</tr>
									<tr>
										<th></th>
										<td>
											<input type="checkbox" name="affiliatemachine_link_nofollow" id="affiliatemachine_link_nofollow" '.($replacement_options['link_nofollow'] == 'on' ? ' checked="checked"' : '').'> '.__('Add "nofollow" attribute', 'affiliatemachine').'
										</td>
									</tr>
									<tr>
										<th>'.__('Maximum replacements per post', 'affiliatemachine').':</th>
										<td>
											<input type="text" name="affiliatemachine_max_keywords" id="affiliatemachine_max_keywords" value="'.$replacement_options['max_keywords'].'" style="width: 80px; text-align: right;">
											<br /><em>'.__('Set maximum replacement per post. Only this number of keywords will be replaced. Set 0 (zero) to replace all keywords.', 'affiliatemachine').'</em>
										</td>
									</tr>
								</table>
								<div class="alignright">
								<input type="hidden" name="ak_action" value="affiliatemachine_update_replacement" />
								'.(!empty($id) ? '<input type="hidden" name="affiliatemachine_id" value="'.$id.'" />' : '').'
								<input type="submit" class="affiliatemachine_button button-primary" name="submit" value="'.__('Submit details', 'affiliatemachine').'">
								</div>
								<br class="clear">
							</div>
						</div>
					</div>
				</div>
			</div>
			</form>
			<script type="text/javascript">
				jQuery(document).ready(function(){
					jQuery("#color_picker_affiliatemachine_keyword_color").farbtastic("#affiliatemachine_keyword_color");
				});
			</script>
		</div>');
	}

	function decode_options($_id) {
		global $wpdb;
		$replacement_details = $wpdb->get_row("SELECT * FROM ".$wpdb->prefix."am_replacements WHERE id = '".$_id."' AND deleted = '0'", ARRAY_A);
		if (intval($replacement_details["id"]) == 0) return array();
		return $this->decode_options_string($replacement_details['options']);
	}

	function decode_options_string($_options) {
		global $wpdb;
		$replacement_options = array();
		$tmp = explode('|', $_options);
		foreach ($tmp as $element) {
			$tmp2 = explode('=', $element);
			if (sizeof($tmp2) == 2 && !empty($tmp2[0])) {
				$replacement_options[$tmp2[0]] = $tmp2[1];
			}
		}
		return $replacement_options;
	}

	function admin_request_handler() {
		global $wpdb;
		if (!empty($_POST['ak_action'])) {
			switch($_POST['ak_action']) {
				case 'affiliatemachine_update_replacement':
					if (isset($_POST["affiliatemachine_id"]) && !empty($_POST["affiliatemachine_id"])) {
						$id = intval($_POST["affiliatemachine_id"]);
						$replacement_details = $wpdb->get_row("SELECT * FROM ".$wpdb->prefix."am_replacements WHERE id = '".$id."' AND deleted = '0'", ARRAY_A);
						if (intval($replacement_details["id"]) == 0) unset($id);
					}
					$replacement_options = array();
					foreach ($this->replacement_default_options as $key => $value) {
						if (isset($_POST['affiliatemachine_'.$key])) {
							$replacement_options[$key] = str_replace("|", "", stripslashes(trim($_POST['affiliatemachine_'.$key])));
						}
					}
					if (isset($_POST["affiliatemachine_keyword_frame"])) $replacement_options['keyword_frame'] = "on";
					else $replacement_options['keyword_frame'] = "off";
					if (isset($_POST["affiliatemachine_keyword_underline"])) $replacement_options['keyword_underline'] = "on";
					else $replacement_options['keyword_underline'] = "off";
					if (isset($_POST["affiliatemachine_keyword_bold"])) $replacement_options['keyword_bold'] = "on";
					else $replacement_options['keyword_bold'] = "off";
					if (isset($_POST["affiliatemachine_link_target"])) $replacement_options['link_target'] = "on";
					else $replacement_options['link_target'] = "off";
					if (isset($_POST["affiliatemachine_link_nofollow"])) $replacement_options['link_nofollow'] = "on";
					else $replacement_options['link_nofollow'] = "off";
					
					$mode = trim(stripslashes($_POST["affiliatemachine_mode"]));
					$name = trim(stripslashes($_POST["affiliatemachine_name"]));
					
					$url = trim(stripslashes($_POST["affiliatemachine_url"]));
					if (!preg_match('|^http(s)?://[a-z0-9-]+(.[a-z0-9-]+)*(:[0-9]+)?(/.*)?$|i', $url) || strlen($url) == 0) {
						$errors[] = __('invalid affiliate URL', 'affiliatemachine');
						$url = get_bloginfo('wpurl');
					}
					
					$keywords = trim(stripslashes($_POST["affiliatemachine_keywords"]));
					$keywords = explode(',', $keywords);
					$keywords_array = array();
					foreach ($keywords as $keyword) {
						$keyword = strtolower(trim($keyword));
						if (strlen($keyword) > 2 && !in_array($keyword, $this->forbidden_keywords)) {
							$keywords_array[] = $keyword;
						}
					}
					$keywords = implode(', ', $keywords_array);
					
					unset($errors);

					if (strlen($name) < 1) {
						$errors[] = __('title is too short', 'affiliatemachine');
						$name = __('Default Replacement', 'affiliatemachine');
					}
					if (!is_numeric($replacement_options['max_keywords']) || intval($replacement_options['max_keywords'] < 0)) {
						$errors[] = __('maximum replacements must be valid value', 'affiliatemachine');
						$replacement_options['max_keywords'] = $this->replacement_default_options['max_keywords'];
					}
					if ($this->get_rgb($replacement_options['keyword_color']) === false) {
						$errors[] = __('keyword color must be valid value', 'affiliatemachine');
						$replacement_options['keyword_color'] = $this->replacement_default_options['keyword_color'];
					}

					$replacement_options_string = '';
					foreach ($replacement_options as $key => $value) {
						$replacement_options_string .= $key.'='.$value.'|';
					}
					if (!empty($replacement_options_string)) $replacement_options_string = substr($replacement_options_string, 0, strlen($replacement_options_string)-1);
					if (!empty($id)) {
						$sql = "UPDATE ".$wpdb->prefix."am_replacements SET
							mode = '".mysql_real_escape_string($mode)."',
							name = '".mysql_real_escape_string($name)."',
							keywords = '".mysql_real_escape_string($keywords)."',
							url = '".mysql_real_escape_string($url)."',
							options = '".mysql_real_escape_string($replacement_options_string)."'
							WHERE id = '".$id."'";
						if ($wpdb->query($sql) !== false) {
							if (is_array($errors)) {
								$message = "The following error(s) occured:<br />- ".implode("<br />- ", $errors);
								setcookie("affiliatemachine_error", $message.'<br />'.__('Tooltip updated with defaut values.', 'affiliatemachine'), time()+30, "/", ".".str_replace("www.", "", $_SERVER["SERVER_NAME"]));
							} else {
								setcookie("affiliatemachine_info", __('Tooltip successfully updated.', 'affiliatemachine'), time()+30, "/", ".".str_replace("www.", "", $_SERVER["SERVER_NAME"]));
							}
							header('Location: '.get_bloginfo("wpurl").'/wp-admin/admin.php?page=affiliate-machine');
							exit;
						} else {
							setcookie("affiliatemachine_error", __('Service is not available', 'affiliatemachine'), time()+30, "/", ".".str_replace("www.", "", $_SERVER["SERVER_NAME"]));
							header('Location: '.get_bloginfo("wpurl").'/wp-admin/admin.php?page=affiliate-machine-add'.(!empty($id) ? '&id='.$id : ''));
							exit;
						}
					} else {
						$sql = "INSERT INTO ".$wpdb->prefix."am_replacements (
							mode, name, keywords, url, options, created, deleted) VALUES (
							'".mysql_real_escape_string($mode)."',
							'".mysql_real_escape_string($name)."',
							'".mysql_real_escape_string($keywords)."',
							'".mysql_real_escape_string($url)."',
							'".mysql_real_escape_string($replacement_options_string)."',
							'".time()."', '0')";
						if ($wpdb->query($sql) !== false) {
							if (is_array($errors)) {
								$message = "The following error(s) occured:<br />- ".implode("<br />- ", $errors);
								setcookie("affiliatemachine_error", $message.'<br />'.__('Tooltip created with defaut values.', 'affiliatemachine'), time()+30, "/", ".".str_replace("www.", "", $_SERVER["SERVER_NAME"]));
							} else {
								setcookie("affiliatemachine_info", __('Tooltip successfully added', 'affiliatemachine'), time()+30, "/", ".".str_replace("www.", "", $_SERVER["SERVER_NAME"]));
							}
							header('Location: '.get_bloginfo("wpurl").'/wp-admin/admin.php?page=affiliate-machine');
							exit;
						} else {
							setcookie("affiliatemachine_error", __('Service is not available', 'affiliatemachine'), time()+30, "/", ".".str_replace("www.", "", $_SERVER["SERVER_NAME"]));
							header('Location: '.get_bloginfo("wpurl").'/wp-admin/admin.php?page=affiliate-machine-add'.(!empty($id) ? '&id='.$id : ''));
							exit;
						}
					}
					break;
				default:
					break;
			}
		}
		if (!empty($_GET['ak_action'])) {
			switch($_GET['ak_action']) {
				case 'affiliatemachine_delete':
					$id = intval($_GET["id"]);
					$replacement_details = $wpdb->get_row("SELECT * FROM ".$wpdb->prefix."am_replacements WHERE id = '".$id."' AND deleted = '0'", ARRAY_A);
					if (intval($replacement_details["id"]) == 0) {
						setcookie("affiliatemachine_error", __('Invalid service call', 'affiliatemachine'), time()+30, "/", ".".str_replace("www.", "", $_SERVER["SERVER_NAME"]));
						header('Location: '.get_bloginfo('wpurl').'/wp-admin/admin.php?page=affiliate-machine');
						die();
					}
					$sql = "UPDATE ".$wpdb->prefix."am_replacements SET deleted = '1' WHERE id = '".$id."'";
					if ($wpdb->query($sql) !== false) {
						setcookie("affiliatemachine_info", __('Tooltip successfully removed', 'affiliatemachine'), time()+30, "/", ".".str_replace("www.", "", $_SERVER["SERVER_NAME"]));
						header('Location: '.get_bloginfo('wpurl').'/wp-admin/admin.php?page=affiliate-machine');
						die();
					} else {
						setcookie("affiliatemachine_error", __('Invalid service call', 'affiliatemachine'), time()+30, "/", ".".str_replace("www.", "", $_SERVER["SERVER_NAME"]));
						header('Location: '.get_bloginfo('wpurl').'/wp-admin/admin.php?page=affiliate-machine');
						die();
					}
					break;
				default:
					break;
			}
		}
	}

	function get_rgb($_color) {
		if (strlen($_color) != 7 && strlen($_color) != 4) return false;
		$color = preg_replace('/[^#a-fA-F0-9]/', '', $_color);
		if (strlen($color) != strlen($_color)) return false;
		if (strlen($color) == 7) list($r, $g, $b) = array($color[1].$color[2], $color[3].$color[4], $color[5].$color[6]);
		else list($r, $g, $b) = array($color[1].$color[1], $color[2].$color[2], $color[3].$color[3]);
		return array("r" => hexdec($r), "g" => hexdec($g), "b" => hexdec($b));
	}

	function admin_header() {
		global $wpdb;
		echo '
		<link rel="stylesheet" type="text/css" href="'.plugins_url('/css/style.css?ver='.AFFILIATEMACHINE_VERSION, __FILE__).'" media="screen" />
		<script type="text/javascript">
			function affiliatemachine_submitOperation() {
				var answer = confirm("Do you really want to remove this item?")
				if (answer) return true;
				else return false;
			}
		</script>';
	}

	function front_header() {
		global $wpdb, $post;
		$sql = "SELECT * FROM ".$wpdb->prefix."am_replacements WHERE deleted = '0' AND (mode = 'all' || mode = 'post')";
		$rows = $wpdb->get_results($sql, ARRAY_A);
		if (sizeof($rows) > 0) {
			echo '
<style type="text/css">';
			foreach ($rows as $row) {
				$replacement_options = $this->decode_options_string($row['options']);
				echo '		
	a.affiliatemachine_'.$row['id'].' {color: '.$replacement_options['keyword_color'].'; '.($replacement_options['keyword_frame'] == 'on' ? '-webkit-box-shadow: #888 0px 0px 5px; box-shadow: #888 0px 0px 5px; -moz-box-shadow: #888 0px 0px 5px; -o-box-shadow: #888 0px 0px 5px; border-radius: 3px; -moz-border-radius: 3px; -webkit-border-radius: 3px; -o-border-radius: 3px;' : '').($replacement_options['keyword_undeline'] == 'on' ? ' text-decoration: underline;' : '').($replacement_options['keyword_bold'] == 'on' ? ' font-weight: bold;' : '').'}';
			}
			echo '
</style>';
		}
	}

	function the_content($_content) {
		global $post, $wpdb;
		$content = $_content;
		$sql = "SELECT * FROM ".$wpdb->prefix."am_replacements WHERE deleted = '0' AND (mode = 'all' || mode = 'post')";
		$rows = $wpdb->get_results($sql, ARRAY_A);
		foreach ($rows as $row) {
			$replace = false;
			$replacement_options = $this->decode_options_string($row['options']);
			if (!empty($row['keywords'])) {
				if ($row["mode"] == 'all') $replace = true;
				if ($post && $row["mode"] == 'post') {
					$meta = $this->get_meta($post->ID);
					$replacements = explode(',', $meta['replacements']);
					if (in_array($row["id"], $replacements)) $replace = true;
				}
			}
			$counter = intval($replacement_options['max_keywords']);
			if ($counter == 0) $counter = 9999;
			
			if ($replace) {
				$keywords = explode(',', $row['keywords']);
				foreach ($keywords as $keyword) {
					if ($counter <= 0) break;
					$keyword = trim($keyword);
					if (!empty($keyword)) {
						$tmp_placeholder = md5($keyword);
						$prefix_yes = md5($tmp_placeholder);
						$prefix_no = md5($prefix_yes);
						$vars = array();
						while (preg_match("~(?<=[\s\p{P}\p{S}\p{C}]|^)(".preg_quote($keyword).")(?=[\s\p{P}\p{S}\p{C}]|$)~sui", $content, $data) > 0 && $counter > 0) {
							if (!array_key_exists($data[0], $vars)) {
								$vars[$data[0]] = sizeof($vars);
							}
							$placeholder_no = $prefix_no.'_'.$vars[$data[0]];
							$placeholder_yes = $prefix_yes.'_'.$vars[$data[0]];
							$content = preg_replace("~(?<=[\s\p{P}\p{S}\p{C}]|^)(".preg_quote($keyword).")(?=[\s\p{P}\p{S}\p{C}]|$)~sui", $tmp_placeholder, $content, 1);
							$content_tmp = preg_replace(
								array(
								  // Remove invisible content
									'@<head[^>]*?>.*?</head>@siu',
									'@<style[^>]*?>.*?</style>@siu',
									'@<script[^>]*?.*?</script>@siu',
									'@<object[^>]*?.*?</object>@siu',
									'@<embed[^>]*?.*?</embed>@siu',
									'@<applet[^>]*?.*?</applet>@siu',
									'@<noframes[^>]*?.*?</noframes>@siu',
									'@<noscript[^>]*?.*?</noscript>@siu',
									'@<noembed[^>]*?.*?</noembed>@siu',
									'@<textarea[^>]*?.*?</textarea>@siu',
									'@<a[^>]*?.*?</a>@siu'
								), array(' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' '), $content);
							$content_tmp = strip_tags($content_tmp);
							if (strpos($content_tmp, $tmp_placeholder) !== false) {
								$content = str_replace($tmp_placeholder, $placeholder_yes, $content);
								$counter--;
							}
							$content = str_replace($tmp_placeholder, $placeholder_no, $content);
						}
						foreach($vars as $key => $value) {
							$content = str_replace($prefix_no.'_'.$value, $key, $content);
							$content = str_replace($prefix_yes.'_'.$value, '<a class="affiliatemachine_'.$row['id'].'" href="'.$row['url'].'" title="'.htmlspecialchars($row['name'], ENT_QUOTES).'"'.($replacement_options['link_target'] == 'on' ? ' target="_blank"' : '').($replacement_options['link_nofollow'] == 'on' ? ' rel="nofollow"' : '').'>'.$key.'</a>', $content);
						}
					}
				}
			}
		}
		return $content;
	}

	function cut_string($_string, $_limit=40) {
		if (strlen($_string) > $_limit) return substr($_string, 0, $_limit-3)."...";
		return $_string;
	}

	function page_switcher ($_urlbase, $_currentpage, $_totalpages) {
		$pageswitcher = "";
		if ($_totalpages > 1) {
			$pageswitcher = '<div class="tablenav bottom"><div class="tablenav-pages">'.__('Pages:', 'affiliatemachine').' <span class="pagiation-links">';
			if (strpos($_urlbase,"?") !== false) $_urlbase .= "&amp;";
			else $_urlbase .= "?";
			if ($_currentpage == 1) $pageswitcher .= "<a class='page disabled'>1</a> ";
			else $pageswitcher .= " <a class='page' href='".$_urlbase."p=1'>1</a> ";

			$start = max($_currentpage-3, 2);
			$end = min(max($_currentpage+3,$start+6), $_totalpages-1);
			$start = max(min($start,$end-6), 2);
			if ($start > 2) $pageswitcher .= " <b>...</b> ";
			for ($i=$start; $i<=$end; $i++) {
				if ($_currentpage == $i) $pageswitcher .= " <a class='page disabled'>".$i."</a> ";
				else $pageswitcher .= " <a class='page' href='".$_urlbase."p=".$i."'>".$i."</a> ";
			}
			if ($end < $_totalpages-1) $pageswitcher .= " <b>...</b> ";

			if ($_currentpage == $_totalpages) $pageswitcher .= " <a class='page disabled'>".$_totalpages."</a> ";
			else $pageswitcher .= " <a class='page' href='".$_urlbase."p=".$_totalpages."'>".$_totalpages."</a> ";
			$pageswitcher .= "</span></div></div>";
		}
		return $pageswitcher;
	}
}
$affiliatemachine = new affiliatemachine_class();
?>